@@ -4,6 +4,12 @@ MIU_TEST_ROOT = dirname(__file__)
 INSTALLED_APPS = ('markitup', 'tests')
 DATABASE_ENGINE = 'sqlite3'
 
+try:
+    import south
+    INSTALLED_APPS += ('south',)
+except ImportError:
+    pass
+
 MEDIA_URL = '/media/'
 MEDIA_ROOT = join(dirname(MIU_TEST_ROOT), 'markitup', 'media')
 
